@@ -14,8 +14,7 @@ from __future__ import absolute_import
 
 from sagemaker_inference.default_handler_service import DefaultHandlerService
 from sagemaker_inference.transformer import Transformer
-from sagemaker_pytorch_serving_container.default_inference_handler import \
-    DefaultPytorchInferenceHandler
+from sagemaker_pytorch_serving_container.default_pytorch_inference_handler import DefaultPytorchInferenceHandler
 
 import os
 import sys
